@@ -8,95 +8,9 @@ use 5.008;
 use Getopt::Long;
 use Pod::Usage;
 
-=head1 NAME
 
-Games::Solitaire::BlackHole::Solver::App - a command line application
-implemented as a class to solve the Black Hole solitaire.
+our $VERSION = '0.0.3';
 
-=head1 VERSION
-
-Version 0.0.2
-
-=cut
-
-our $VERSION = '0.0.2';
-
-=head1 SYNOPSIS
-
-    use Games::Solitaire::BlackHole::Solver::App;
-
-    my $app = Games::Solitaire::BlackHole::Solver::App->new;
-
-    $app->run();
-
-And then from the command-line:
-
-    $ black-hole-solve myboard.txt
-
-=head1 DESCRIPTION
-
-A script that encapsulates this application accepts a filename pointing
-at the file containing the board or C<"-"> for specifying the standard input.
-
-A board looks like this and can be generated for PySol using the
-make_pysol_board.py in the contrib/ .
-
-    Foundations: AS
-    KD JH JS
-    8H 4C 7D
-    7H TD 4H
-    JD 9S 5S
-    AH 3S 6H
-    9C 9D 8S
-    7S 2H 6S
-    AC JC QH
-    QD 4S TS
-    6C QS QC
-    8D 3D KH
-    5H 5C 8C
-    4D KC TC
-    6D 3C 3H
-    2C KS TH
-    AD 5D 7C
-    9H 2S 2D
-
-Other flags:
-
-=over 4
-
-=item * --version
-
-=item * --help
-
-=item * --man
-
-=item * -o/--output solution_file.txt
-
-Output to a solution file.
-
-=back
-
-More information about Black Hole Solitaire can be found at:
-
-=over 4
-
-=item * L<http://en.wikipedia.org/wiki/Black_Hole_%28solitaire%29>
-
-=item * L<http://pysolfc.sourceforge.net/doc/rules/blackhole.html>
-
-=back
-
-=head1 METHODS
-
-=head2 $self->new()
-
-Instantiates an object.
-
-=head2 $self->run()
-
-Runs the application.
-
-=cut
 
 sub new
 {
@@ -281,6 +195,103 @@ sub run
     exit(! $verdict);
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::Solitaire::BlackHole::Solver::App - a command line application
+implemented as a class to solve the Black Hole solitaire.
+
+=head1 VERSION
+
+version 0.0.3
+
+=head1 SYNOPSIS
+
+    use Games::Solitaire::BlackHole::Solver::App;
+
+    my $app = Games::Solitaire::BlackHole::Solver::App->new;
+
+    $app->run();
+
+And then from the command-line:
+
+    $ black-hole-solve myboard.txt
+
+=head1 DESCRIPTION
+
+A script that encapsulates this application accepts a filename pointing
+at the file containing the board or C<"-"> for specifying the standard input.
+
+A board looks like this and can be generated for PySol using the
+make_pysol_board.py in the contrib/ .
+
+    Foundations: AS
+    KD JH JS
+    8H 4C 7D
+    7H TD 4H
+    JD 9S 5S
+    AH 3S 6H
+    9C 9D 8S
+    7S 2H 6S
+    AC JC QH
+    QD 4S TS
+    6C QS QC
+    8D 3D KH
+    5H 5C 8C
+    4D KC TC
+    6D 3C 3H
+    2C KS TH
+    AD 5D 7C
+    9H 2S 2D
+
+Other flags:
+
+=over 4
+
+=item * --version
+
+=item * --help
+
+=item * --man
+
+=item * -o/--output solution_file.txt
+
+Output to a solution file.
+
+=back
+
+More information about Black Hole Solitaire can be found at:
+
+=over 4
+
+=item * L<http://en.wikipedia.org/wiki/Black_Hole_%28solitaire%29>
+
+=item * L<http://pysolfc.sourceforge.net/doc/rules/blackhole.html>
+
+=back
+
+=head1 VERSION
+
+Version 0.0.3
+
+=head1 METHODS
+
+=head2 $self->new()
+
+Instantiates an object.
+
+=head2 $self->run()
+
+Runs the application.
+
 =head1 SEE ALSO
 
 The Black Hole Solitaire Solvers homepage is at
@@ -325,7 +336,141 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-BlackHole-Solver
+or by email to bug-games-solitaire-blackhole-solver@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Games::Solitaire::BlackHole::Solver
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-Solitaire-BlackHole-Solver>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::Solitaire::BlackHole::Solver>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-games-solitaire-blackhole-solver at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-Solitaire-BlackHole-Solver>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/black-hole-solitaire>
+
+  git clone https://github.com/shlomif/black-hole-solitaire
+
 =cut
-
-1;
-
